==> eda4treeR_0.6.0.tar.gz: eda4treeR/README.md <==

# `eda4treeR`: Experimental Design and Analysis for Tree Improvement <img src = "man/figures/eda4treeR_hexSticker.png" align = "right" height = "140/"/>

###### Version : [0.6.0](https://myaseen208.com/eda4treeR/); License: [GPL-2\|GPL-3](https://www.r-project.org/Licenses/)

##### *Muhammad Yaseen<sup>1,2,3</sup>, Sami Ullah<sup>4</sup>, Kent M. Eskridge<sup>5</sup>, Emlyn Williams<sup>6</sup>*

1.  [Asian Development Bank (ADB), Islamabad,
    Pakistan](https://myaseen208.com/)
2.  [Benazir Income Support Programme (BISP), Islamabad,
    Pakistan](https://myaseen208.com/)
3.  [Department of Mathematics and Statistics, University of Agriculture
    Faisalabad, Pakistan](https://myaseen208.com/)
4.  College of Agriculutre, University of Sargodha, Pakistan
5.  [Department of Statistics, University of Nebraska-Lincoln, Lincoln
    NE, USA](https://statistics.unl.edu/kent-m-eskridge)
6.  [Australian National University, Canberra, ACT,
    Australia](https://services.anu.edu.au/business-units/research-initiatives-and-infrastructure/statistical-support-network/associate)

------------------------------------------------------------------------

[![minimal R
version](https://img.shields.io/badge/R%3E%3D-2.10.0-6666ff.svg)](https://cran.r-project.org/)
[![License: GPL
v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version-last-release/eda4treeR)](https://cran.r-project.org/package=eda4treeR)
[![rstudio mirror
downloads](https://cranlogs.r-pkg.org/badges/grand-total/eda4treeR?color=green)](https://CRAN.R-project.org/package=eda4treeR)
<!-- [![packageversion](https://img.shields.io/badge/Package%20version-0.2.3.3-orange.svg)](https://github.com/myaseen208/eda4treeR) -->

[![develVersion](https://img.shields.io/badge/devel%20version-0.5.0-orange.svg)](https://github.com/myaseen208/eda4treeR)

<!-- [![GitHub Download Count](https://github-basic-badges.herokuapp.com/downloads/myaseen208/eda4treeR/total.svg)] -->

[![Project Status:
WIP](https://www.repostatus.org/badges/latest/inactive.svg)](https://www.repostatus.org/#inactive)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Last-changedate](https://img.shields.io/badge/last%20change-2023--05--01-yellowgreen.svg)](https://github.com/myaseen208/eda4treeR)

------------------------------------------------------------------------

## Description

Provides data sets and R Codes for E.R. Williams, C.E. Harwood and A.C.
Matheson (2023). Experimental Design and Analysis for Tree Improvement,
CSIRO Publishing.

   

## Installation

The package can be installed from CRAN as follows:

``` r
install.packages("eda4treeR", dependencies = TRUE)
```

 

The development version can be installed from github as follows:

``` r
if (!require("remotes")) install.packages("remotes")
remotes::install_github("myaseen208/eda4treeR")
```

   

## What’s new

To know whats new in this version type:

``` r
news(package = "eda4treeR")
```

## Links

[CRAN page](https://cran.r-project.org/package=eda4treeR)

[Github page](https://github.com/myaseen208/eda4treeR)

[Documentation website](https://myaseen208.com/eda4treeR/)

[Companion website](https://myaseen208.com/EDATR/)

## Citing `eda4treeR`

To cite the R package `eda4treeR` in publications use:

``` r
citation("eda4treeR")
```

==> eda4treeR_1.1.0.tar.gz: eda4treeR/README.md <==

# `eda4treeR`: Experimental Design and Analysis for Tree Improvement <img src = "man/figures/eda4treeR_hexSticker.png" align = "right" height = "140/"/>

###### Version : [0.6.0](https://myaseen208.com/eda4treeR/); License: [GPL-2\|GPL-3](https://www.r-project.org/Licenses/)

##### *Muhammad Yaseen<sup>1,2,3</sup>, Sami Ullah<sup>4</sup>, Kent M. Eskridge<sup>5</sup>, Emlyn Williams<sup>6</sup>*

1.  [Asian Development Bank (ADB), Islamabad,
    Pakistan](https://myaseen208.com/)
2.  [Benazir Income Support Programme (BISP), Islamabad,
    Pakistan](https://myaseen208.com/)
3.  [Department of Mathematics and Statistics, University of Agriculture
    Faisalabad, Pakistan](https://myaseen208.com/)
4.  College of Agriculutre, University of Sargodha, Pakistan
5.  [Department of Statistics, University of Nebraska-Lincoln, Lincoln
    NE, USA](https://statistics.unl.edu/kent-m-eskridge)
6.  [Australian National University, Canberra, ACT,
    Australia](https://services.anu.edu.au/business-units/research-initiatives-and-infrastructure/statistical-support-network/associate-professor-emlyn-williams)

------------------------------------------------------------------------

[![minimal R
version](https://img.shields.io/badge/R%3E%3D-2.10.0-6666ff.svg)](https://cran.r-project.org/)
[![License: GPL
v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version-last-release/eda4treeR)](https://cran.r-project.org/package=eda4treeR)
[![rstudio mirror
downloads](https://cranlogs.r-pkg.org/badges/grand-total/eda4treeR?color=green)](https://CRAN.R-project.org/package=eda4treeR)
<!-- [![packageversion](https://img.shields.io/badge/Package%20version-0.2.3.3-orange.svg)](https://github.com/myaseen208/eda4treeR) -->

[![develVersion](https://img.shields.io/badge/devel%20version-0.5.0-orange.svg)](https://github.com/myaseen208/eda4treeR)

<!-- [![GitHub Download Count](https://github-basic-badges.herokuapp.com/downloads/myaseen208/eda4treeR/total.svg)] -->

[![Project Status:
WIP](https://www.repostatus.org/badges/latest/inactive.svg)](https://www.repostatus.org/#inactive)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Last-changedate](https://img.shields.io/badge/last%20change-2023--05--01-yellowgreen.svg)](https://github.com/myaseen208/eda4treeR)

------------------------------------------------------------------------

## Description

Provides data sets and R Codes for E.R. Williams, C.E. Harwood and A.C.
Matheson (2023). Experimental Design and Analysis for Tree Improvement,
CSIRO Publishing.

   

## Installation

The package can be installed from CRAN as follows:

``` r
install.packages("eda4treeR", dependencies = TRUE)
```

 

The development version can be installed from github as follows:

``` r
if (!require("remotes")) install.packages("remotes")
remotes::install_github("myaseen208/eda4treeR")
```

   

## What’s new

To know whats new in this version type:

``` r
news(package = "eda4treeR")
```

## Links

[CRAN page](https://cran.r-project.org/package=eda4treeR)

[Github page](https://github.com/myaseen208/eda4treeR)

[Documentation website](https://myaseen208.com/eda4treeR/)

[Companion website](https://myaseen208.com/EDATR/)

## Citing `eda4treeR`

To cite the R package `eda4treeR` in publications use:

``` r
citation("eda4treeR")
```
